/*
 *  sbcexample.java
 *
 * This simple example creates a Phidget with listeners and opens the device.
 * It reads the status of the inputs and outputs then waits for an InterfaceKit 
 * to be attached and waits for events to be fired.
 * Digital Ouput 0 will trigger on when any sensor value is greater than 500.
 *
 * Modified by Kat Dornian on 2014-04-08.
 *
 * Copyright 2014 Phidgets Inc.
 * This work is licensed under the Creative Commons Attribution 2.5 Canada License.
 * To view a copy of this license, visit http://creativecommons.org/licenses/by/2.5/ca/
 *
 */

import com.phidgets.*;
import com.phidgets.event.*;

public class sbcexample
{
	public static final void main(String args[]) throws Exception {
        final InterfaceKitPhidget ik;
        
		//Example of enabling logging.
		//Phidget.enableLogging(Phidget.PHIDGET_LOG_VERBOSE, null);
        
		System.out.println(Phidget.getLibraryVersion());
        
		ik = new InterfaceKitPhidget();
		ik.addAttachListener(new AttachListener() {
			public void attached(AttachEvent ae) {
				System.out.println("attachment of " + ae);
			}
		});
		ik.addDetachListener(new DetachListener() {
			public void detached(DetachEvent ae) {
				System.out.println("detachment of " + ae);
			}
		});
		ik.addErrorListener(new ErrorListener() {
			public void error(ErrorEvent ee) {
				System.out.println(ee);
			}
		});
		ik.addInputChangeListener(new InputChangeListener() {
			public void inputChanged(InputChangeEvent oe) {
                
                System.out.println("Digital Input: " + oe.getIndex() + " > State: " + oe.getState() );
			}
		});
		ik.addOutputChangeListener(new OutputChangeListener() {
			public void outputChanged(OutputChangeEvent oe) {
                
                System.out.println("Digital Output: " + oe.getIndex() + " > State: " + oe.getState() );
			}
		});
		ik.addSensorChangeListener(new SensorChangeListener() {
			public void sensorChanged(SensorChangeEvent se) {
                
                int value;
                
                value = se.getValue();
                
                if (value > 500) {
                    try {
                        ik.setOutputState(0, true);
                    } catch (Exception e) {
                    }
                }
                else {
                    try {
                        ik.setOutputState(0, false);
                    } catch (Exception e) {
                    }
                }
                
                System.out.println("Sensor: " + se.getIndex() + " > State: " + value );
			}
		});
        
        //Attach the interface kit
		ik.openAny();
		System.out.println("Waiting for InterfaceKit attachment...");
		ik.waitForAttachment();
        
		System.out.println(ik.getDeviceName());
        
        //Flash the LED quickly
        ik.setOutputState(0, true);
        Thread.sleep(50);
        ik.setOutputState(0, false);
        
		Thread.sleep(30000);
        
        /* Comment this loop out if running from terminal
        for ( ; ; ) {
            try {
                Thread.sleep(30000);
            } catch (Exception e) {
            }
        }*/
        
        //All Done, close and exit
		System.out.print("closing...");
        
        //Make sure our light is off
        ik.setOutputState(0, false);
		ik.close();
		System.out.println(" ok");
        System.gc();
        
	}
}
